@@ -24,7 +24,7 @@
 template <typename T1, typename T2>
 inline void glue_solve_gen_default::apply(Mat<typename T1::elem_type>& out,
                                           const Glue<T1, T2, glue_solve_gen_default>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool status = glue_solve_gen_default::apply(out, X.A, X.B);
 
@@ -37,7 +37,7 @@ inline void glue_solve_gen_default::apply(Mat<typename T1::elem_type>& out,
 template <typename eT, typename T1, typename T2>
 inline bool glue_solve_gen_default::apply(Mat<eT>& out, const Base<eT, T1>& A_expr,
                                           const Base<eT, T2>& B_expr) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return glue_solve_gen_full::apply<eT, T1, T2, false>(out, A_expr, B_expr, uword(0));
 }
@@ -48,7 +48,7 @@ inline bool glue_solve_gen_default::apply(Mat<eT>& out, const Base<eT, T1>& A_ex
 template <typename T1, typename T2>
 inline void glue_solve_gen_full::apply(Mat<typename T1::elem_type>& out,
                                        const Glue<T1, T2, glue_solve_gen_full>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool status = glue_solve_gen_full::apply(out, X.A, X.B, X.aux_uword);
 
@@ -61,15 +61,15 @@ inline void glue_solve_gen_full::apply(Mat<typename T1::elem_type>& out,
 template <typename eT, typename T1, typename T2, const bool has_user_flags>
 inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>& A_expr,
                                        const Base<eT, T2>& B_expr, const uword flags) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename get_pod_type<eT>::result T;
 
   if (has_user_flags == true) {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): has_user_flags = true");
+    arma_debug_print("glue_solve_gen_full::apply(): has_user_flags = true");
   }
   if (has_user_flags == false) {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): has_user_flags = false");
+    arma_debug_print("glue_solve_gen_full::apply(): has_user_flags = false");
   }
 
   const bool fast = has_user_flags && bool(flags & solve_opts::flag_fast);
@@ -84,44 +84,45 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   const bool force_approx = has_user_flags && bool(flags & solve_opts::flag_force_approx);
 
   if (has_user_flags) {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): enabled flags:");
+    arma_debug_print("glue_solve_gen_full::apply(): enabled flags:");
 
     if (fast) {
-      arma_extra_debug_print("fast");
+      arma_debug_print("fast");
     }
     if (equilibrate) {
-      arma_extra_debug_print("equilibrate");
+      arma_debug_print("equilibrate");
     }
     if (no_approx) {
-      arma_extra_debug_print("no_approx");
+      arma_debug_print("no_approx");
     }
     if (no_band) {
-      arma_extra_debug_print("no_band");
+      arma_debug_print("no_band");
     }
     if (no_sympd) {
-      arma_extra_debug_print("no_sympd");
+      arma_debug_print("no_sympd");
     }
     if (allow_ugly) {
-      arma_extra_debug_print("allow_ugly");
+      arma_debug_print("allow_ugly");
     }
     if (likely_sympd) {
-      arma_extra_debug_print("likely_sympd");
+      arma_debug_print("likely_sympd");
     }
     if (refine) {
-      arma_extra_debug_print("refine");
+      arma_debug_print("refine");
     }
     if (no_trimat) {
-      arma_extra_debug_print("no_trimat");
+      arma_debug_print("no_trimat");
     }
     if (force_approx) {
-      arma_extra_debug_print("force_approx");
+      arma_debug_print("force_approx");
     }
 
-    arma_debug_check((fast && equilibrate),
-                     "solve(): options 'fast' and 'equilibrate' are mutually exclusive");
-    arma_debug_check((fast && refine),
-                     "solve(): options 'fast' and 'refine' are mutually exclusive");
-    arma_debug_check(
+    arma_conform_check(
+        (fast && equilibrate),
+        "solve(): options 'fast' and 'equilibrate' are mutually exclusive");
+    arma_conform_check((fast && refine),
+                       "solve(): options 'fast' and 'refine' are mutually exclusive");
+    arma_conform_check(
         (no_sympd && likely_sympd),
         "solve(): options 'no_sympd' and 'likely_sympd' are mutually exclusive");
   }
@@ -129,27 +130,25 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   Mat<eT> A = A_expr.get_ref();
 
   if (force_approx) {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): forced approximate solution");
+    arma_debug_print("glue_solve_gen_full::apply(): forced approximate solution");
 
-    arma_debug_check(
+    arma_conform_check(
         no_approx,
         "solve(): options 'no_approx' and 'force_approx' are mutually exclusive");
 
     if (fast) {
-      arma_debug_warn_level(
-          2, "solve(): option 'fast' ignored for forced approximate solution");
+      arma_warn(2, "solve(): option 'fast' ignored for forced approximate solution");
     }
     if (equilibrate) {
-      arma_debug_warn_level(
-          2, "solve(): option 'equilibrate' ignored for forced approximate solution");
+      arma_warn(2,
+                "solve(): option 'equilibrate' ignored for forced approximate solution");
     }
     if (refine) {
-      arma_debug_warn_level(
-          2, "solve(): option 'refine' ignored for forced approximate solution");
+      arma_warn(2, "solve(): option 'refine' ignored for forced approximate solution");
     }
     if (likely_sympd) {
-      arma_debug_warn_level(
-          2, "solve(): option 'likely_sympd' ignored for forced approximate solution");
+      arma_warn(2,
+                "solve(): option 'likely_sympd' ignored for forced approximate solution");
     }
 
     return auxlib::solve_approx_svd(actual_out, A, B_expr.get_ref());  // A is overwritten
@@ -174,7 +173,7 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   bool status = false;
 
   if (A.n_rows == A.n_cols) {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): detected square system");
+    arma_debug_print("glue_solve_gen_full::apply(): detected square system");
 
     uword KL = 0;
     uword KU = 0;
@@ -201,25 +200,25 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
     if (fast) {
       // fast mode: solvers without refinement and without rcond estimate
 
-      arma_extra_debug_print("glue_solve_gen_full::apply(): fast mode");
+      arma_debug_print("glue_solve_gen_full::apply(): fast mode");
 
       if (is_band) {
         if ((KL == 1) && (KU == 1)) {
-          arma_extra_debug_print("glue_solve_gen_full::apply(): fast + tridiagonal");
+          arma_debug_print("glue_solve_gen_full::apply(): fast + tridiagonal");
 
           status = auxlib::solve_tridiag_fast(out, A, B_expr.get_ref());
         } else {
-          arma_extra_debug_print("glue_solve_gen_full::apply(): fast + band");
+          arma_debug_print("glue_solve_gen_full::apply(): fast + band");
 
           status = auxlib::solve_band_fast(out, A, KL, KU, B_expr.get_ref());
         }
       } else if (is_triu || is_tril) {
         if (is_triu) {
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): fast + upper triangular matrix");
         }
         if (is_tril) {
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): fast + lower triangular matrix");
         }
 
@@ -227,14 +226,14 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
 
         status = auxlib::solve_trimat_fast(out, A, B_expr.get_ref(), layout);
       } else if (try_sympd) {
-        arma_extra_debug_print("glue_solve_gen_full::apply(): fast + try_sympd");
+        arma_debug_print("glue_solve_gen_full::apply(): fast + try_sympd");
 
         status = auxlib::solve_sympd_fast(out, A, B_expr.get_ref());  // A is overwritten
 
         if (status == false) {
           // auxlib::solve_sympd_fast() may have failed because A isn't really sympd
 
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): auxlib::solve_sympd_fast() failed; "
               "retrying");
 
@@ -244,21 +243,21 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
               auxlib::solve_square_fast(out, A, B_expr.get_ref());  // A is overwritten
         }
       } else {
-        arma_extra_debug_print("glue_solve_gen_full::apply(): fast + dense");
+        arma_debug_print("glue_solve_gen_full::apply(): fast + dense");
 
         status = auxlib::solve_square_fast(out, A, B_expr.get_ref());  // A is overwritten
       }
     } else if (refine || equilibrate) {
       // refine mode: solvers with refinement and with rcond estimate
 
-      arma_extra_debug_print("glue_solve_gen_full::apply(): refine mode");
+      arma_debug_print("glue_solve_gen_full::apply(): refine mode");
 
       if (is_band) {
-        arma_extra_debug_print("glue_solve_gen_full::apply(): refine + band");
+        arma_debug_print("glue_solve_gen_full::apply(): refine + band");
 
         status = auxlib::solve_band_refine(out, rcond, A, KL, KU, B_expr, equilibrate);
       } else if (try_sympd) {
-        arma_extra_debug_print("glue_solve_gen_full::apply(): refine + try_sympd");
+        arma_debug_print("glue_solve_gen_full::apply(): refine + try_sympd");
 
         status = auxlib::solve_sympd_refine(out, rcond, A, B_expr.get_ref(),
                                             equilibrate);  // A is overwritten
@@ -267,7 +266,7 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
           // auxlib::solve_sympd_refine() may have failed because A isn't really sympd;
           // in that case rcond is set to zero
 
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): auxlib::solve_sympd_refine() failed; "
               "retrying");
 
@@ -277,7 +276,7 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
                                                equilibrate);  // A is overwritten
         }
       } else {
-        arma_extra_debug_print("glue_solve_gen_full::apply(): refine + dense");
+        arma_debug_print("glue_solve_gen_full::apply(): refine + dense");
 
         status = auxlib::solve_square_refine(out, rcond, A, B_expr,
                                              equilibrate);  // A is overwritten
@@ -285,19 +284,19 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
     } else {
       // default mode: solvers without refinement but with rcond estimate
 
-      arma_extra_debug_print("glue_solve_gen_full::apply(): default mode");
+      arma_debug_print("glue_solve_gen_full::apply(): default mode");
 
       if (is_band) {
-        arma_extra_debug_print("glue_solve_gen_full::apply(): rcond + band");
+        arma_debug_print("glue_solve_gen_full::apply(): rcond + band");
 
         status = auxlib::solve_band_rcond(out, rcond, A, KL, KU, B_expr.get_ref());
       } else if (is_triu || is_tril) {
         if (is_triu) {
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): rcond + upper triangular matrix");
         }
         if (is_tril) {
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): rcond + lower triangular matrix");
         }
 
@@ -311,7 +310,7 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
                                            B_expr.get_ref());  // A is overwritten
 
         if ((status == false) && (sympd_state == false)) {
-          arma_extra_debug_print(
+          arma_debug_print(
               "glue_solve_gen_full::apply(): auxlib::solve_sympd_rcond() failed; "
               "retrying");
 
@@ -326,18 +325,16 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
       }
     }
   } else {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): detected non-square system");
+    arma_debug_print("glue_solve_gen_full::apply(): detected non-square system");
 
     if (equilibrate) {
-      arma_debug_warn_level(
-          2, "solve(): option 'equilibrate' ignored for non-square matrix");
+      arma_warn(2, "solve(): option 'equilibrate' ignored for non-square matrix");
     }
     if (refine) {
-      arma_debug_warn_level(2, "solve(): option 'refine' ignored for non-square matrix");
+      arma_warn(2, "solve(): option 'refine' ignored for non-square matrix");
     }
     if (likely_sympd) {
-      arma_debug_warn_level(
-          2, "solve(): option 'likely_sympd' ignored for non-square matrix");
+      arma_warn(2, "solve(): option 'likely_sympd' ignored for non-square matrix");
     }
 
     if (fast) {
@@ -354,13 +351,13 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   }
 
   if ((status == false) && (no_approx == false)) {
-    arma_extra_debug_print("glue_solve_gen_full::apply(): solving rank deficient system");
+    arma_debug_print("glue_solve_gen_full::apply(): solving rank deficient system");
 
     if (rcond == T(0)) {
-      arma_debug_warn_level(2, "solve(): system is singular; attempting approx solution");
+      arma_warn(2, "solve(): system is singular; attempting approx solution");
     } else {
-      arma_debug_warn_level(2, "solve(): system is singular (rcond: ", rcond,
-                            "); attempting approx solution");
+      arma_warn(2, "solve(): system is singular (rcond: ", rcond,
+                "); attempting approx solution");
     }
 
     // TODO: conditionally recreate A: have a separate state flag which indicates whether
@@ -384,7 +381,7 @@ inline bool glue_solve_gen_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
 template <typename T1, typename T2>
 inline void glue_solve_tri_default::apply(Mat<typename T1::elem_type>& out,
                                           const Glue<T1, T2, glue_solve_tri_default>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool status = glue_solve_tri_default::apply(out, X.A, X.B, X.aux_uword);
 
@@ -397,27 +394,27 @@ inline void glue_solve_tri_default::apply(Mat<typename T1::elem_type>& out,
 template <typename eT, typename T1, typename T2>
 inline bool glue_solve_tri_default::apply(Mat<eT>& actual_out, const Base<eT, T1>& A_expr,
                                           const Base<eT, T2>& B_expr, const uword flags) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename get_pod_type<eT>::result T;
 
   const bool triu = bool(flags & solve_opts::flag_triu);
   const bool tril = bool(flags & solve_opts::flag_tril);
 
-  arma_extra_debug_print("glue_solve_tri_default::apply(): enabled flags:");
+  arma_debug_print("glue_solve_tri_default::apply(): enabled flags:");
 
   if (triu) {
-    arma_extra_debug_print("triu");
+    arma_debug_print("triu");
   }
   if (tril) {
-    arma_extra_debug_print("tril");
+    arma_debug_print("tril");
   }
 
   const quasi_unwrap<T1> UA(A_expr.get_ref());
   const Mat<eT>& A = UA.M;
 
-  arma_debug_check((A.is_square() == false),
-                   "solve(): matrix marked as triangular must be square sized");
+  arma_conform_check((A.is_square() == false),
+                     "solve(): matrix marked as triangular must be square sized");
 
   const uword layout = (triu) ? uword(0) : uword(1);
 
@@ -444,14 +441,13 @@ inline bool glue_solve_tri_default::apply(Mat<eT>& actual_out, const Base<eT, T1
   }
 
   if (status == false) {
-    arma_extra_debug_print(
-        "glue_solve_tri_default::apply(): solving rank deficient system");
+    arma_debug_print("glue_solve_tri_default::apply(): solving rank deficient system");
 
     if (rcond == T(0)) {
-      arma_debug_warn_level(2, "solve(): system is singular; attempting approx solution");
+      arma_warn(2, "solve(): system is singular; attempting approx solution");
     } else {
-      arma_debug_warn_level(2, "solve(): system is singular (rcond: ", rcond,
-                            "); attempting approx solution");
+      arma_warn(2, "solve(): system is singular (rcond: ", rcond,
+                "); attempting approx solution");
     }
 
     Mat<eT> triA =
@@ -474,7 +470,7 @@ inline bool glue_solve_tri_default::apply(Mat<eT>& actual_out, const Base<eT, T1
 template <typename T1, typename T2>
 inline void glue_solve_tri_full::apply(Mat<typename T1::elem_type>& out,
                                        const Glue<T1, T2, glue_solve_tri_full>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool status = glue_solve_tri_full::apply(out, X.A, X.B, X.aux_uword);
 
@@ -487,7 +483,7 @@ inline void glue_solve_tri_full::apply(Mat<typename T1::elem_type>& out,
 template <typename eT, typename T1, typename T2>
 inline bool glue_solve_tri_full::apply(Mat<eT>& actual_out, const Base<eT, T1>& A_expr,
                                        const Base<eT, T2>& B_expr, const uword flags) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename get_pod_type<eT>::result T;
 
@@ -502,37 +498,37 @@ inline bool glue_solve_tri_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   const bool no_trimat = bool(flags & solve_opts::flag_no_trimat);
   const bool force_approx = bool(flags & solve_opts::flag_force_approx);
 
-  arma_extra_debug_print("glue_solve_tri_full::apply(): enabled flags:");
+  arma_debug_print("glue_solve_tri_full::apply(): enabled flags:");
 
   if (fast) {
-    arma_extra_debug_print("fast");
+    arma_debug_print("fast");
   }
   if (equilibrate) {
-    arma_extra_debug_print("equilibrate");
+    arma_debug_print("equilibrate");
   }
   if (no_approx) {
-    arma_extra_debug_print("no_approx");
+    arma_debug_print("no_approx");
   }
   if (triu) {
-    arma_extra_debug_print("triu");
+    arma_debug_print("triu");
   }
   if (tril) {
-    arma_extra_debug_print("tril");
+    arma_debug_print("tril");
   }
   if (allow_ugly) {
-    arma_extra_debug_print("allow_ugly");
+    arma_debug_print("allow_ugly");
   }
   if (likely_sympd) {
-    arma_extra_debug_print("likely_sympd");
+    arma_debug_print("likely_sympd");
   }
   if (refine) {
-    arma_extra_debug_print("refine");
+    arma_debug_print("refine");
   }
   if (no_trimat) {
-    arma_extra_debug_print("no_trimat");
+    arma_debug_print("no_trimat");
   }
   if (force_approx) {
-    arma_extra_debug_print("force_approx");
+    arma_debug_print("force_approx");
   }
 
   if (no_trimat || equilibrate || refine || force_approx) {
@@ -544,15 +540,14 @@ inline bool glue_solve_tri_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   }
 
   if (likely_sympd) {
-    arma_debug_warn_level(2,
-                          "solve(): option 'likely_sympd' ignored for triangular matrix");
+    arma_warn(2, "solve(): option 'likely_sympd' ignored for triangular matrix");
   }
 
   const quasi_unwrap<T1> UA(A_expr.get_ref());
   const Mat<eT>& A = UA.M;
 
-  arma_debug_check((A.is_square() == false),
-                   "solve(): matrix marked as triangular must be square sized");
+  arma_conform_check((A.is_square() == false),
+                     "solve(): matrix marked as triangular must be square sized");
 
   const uword layout = (triu) ? uword(0) : uword(1);
 
@@ -584,13 +579,13 @@ inline bool glue_solve_tri_full::apply(Mat<eT>& actual_out, const Base<eT, T1>&
   }
 
   if ((status == false) && (no_approx == false)) {
-    arma_extra_debug_print("glue_solve_tri_full::apply(): solving rank deficient system");
+    arma_debug_print("glue_solve_tri_full::apply(): solving rank deficient system");
 
     if (rcond == T(0)) {
-      arma_debug_warn_level(2, "solve(): system is singular; attempting approx solution");
+      arma_warn(2, "solve(): system is singular; attempting approx solution");
     } else {
-      arma_debug_warn_level(2, "solve(): system is singular (rcond: ", rcond,
-                            "); attempting approx solution");
+      arma_warn(2, "solve(): system is singular (rcond: ", rcond,
+                "); attempting approx solution");
     }
 
     Mat<eT> triA =
