@@ -22,7 +22,7 @@ template <bool do_inv_detect>
 template <typename T1, typename T2>
 inline void glue_times_redirect2_helper<do_inv_detect>::apply(
     Mat<typename T1::elem_type>& out, const Glue<T1, T2, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -32,9 +32,25 @@ inline void glue_times_redirect2_helper<do_inv_detect>::apply(
   const typename partial_unwrap<T1>::stored_type& A = tmp1.M;
   const typename partial_unwrap<T2>::stored_type& B = tmp2.M;
 
-  const bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
+  constexpr bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
   const eT alpha = use_alpha ? (tmp1.get_val() * tmp2.get_val()) : eT(0);
 
+  if ((is_cx<eT>::no) &&
+      (resolves_to_rowvector<T1>::value && resolves_to_colvector<T2>::value)) {
+    arma_debug_print("glue_times: dot product optimisation");
+
+    arma_conform_assert_mul_size(A, B, tmp1.do_trans, tmp2.do_trans,
+                                 "matrix multiplication");
+
+    const eT val = op_dot::direct_dot(A.n_elem, A.memptr(), B.memptr());
+
+    out.set_size(1, 1);
+
+    out[0] = (use_alpha) ? (val * alpha) : (val);
+
+    return;
+  }
+
   const bool alias = tmp1.is_alias(out) || tmp2.is_alias(out);
 
   if (alias == false) {
@@ -55,7 +71,7 @@ inline void glue_times_redirect2_helper<do_inv_detect>::apply(
 template <typename T1, typename T2>
 inline void glue_times_redirect2_helper<true>::apply(Mat<typename T1::elem_type>& out,
                                                      const Glue<T1, T2, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -63,29 +79,29 @@ inline void glue_times_redirect2_helper<true>::apply(Mat<typename T1::elem_type>
       (strip_inv<T1>::do_inv_gen || strip_inv<T1>::do_inv_spd)) {
     // replace inv(A)*B with solve(A,B)
 
-    arma_extra_debug_print("glue_times_redirect<2>::apply(): detected inv(A)*B");
+    arma_debug_print("glue_times_redirect<2>::apply(): detected inv(A)*B");
 
     const strip_inv<T1> A_strip(X.A);
 
     Mat<eT> A = A_strip.M;
 
-    arma_debug_check((A.is_square() == false),
-                     "inv(): given matrix must be square sized");
+    arma_conform_check((A.is_square() == false),
+                       "inv(): given matrix must be square sized");
 
-    if ((strip_inv<T1>::do_inv_spd) && (arma_config::debug) &&
+    if ((strip_inv<T1>::do_inv_spd) && (arma_config::check_conform) &&
         (auxlib::rudimentary_sym_check(A) == false)) {
       if (is_cx<eT>::no) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not symmetric");
+        arma_warn(1, "inv_sympd(): given matrix is not symmetric");
       }
       if (is_cx<eT>::yes) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not hermitian");
+        arma_warn(1, "inv_sympd(): given matrix is not hermitian");
       }
     }
 
     const unwrap_check<T2> B_tmp(X.B, out);
     const Mat<eT>& B = B_tmp.M;
 
-    arma_debug_assert_mul_size(A, B, "matrix multiplication");
+    arma_conform_assert_mul_size(A, B, "matrix multiplication");
 
     const bool status = (strip_inv<T1>::do_inv_spd)
                             ? auxlib::solve_sympd_fast(out, A, B)
@@ -105,7 +121,7 @@ inline void glue_times_redirect2_helper<true>::apply(Mat<typename T1::elem_type>
     // replace A*inv_sympd(B) with trans( solve(trans(B),trans(A)) )
     // transpose of B is avoided as B is explicitly marked as symmetric
 
-    arma_extra_debug_print("glue_times_redirect<2>::apply(): detected A*inv_sympd(B)");
+    arma_debug_print("glue_times_redirect<2>::apply(): detected A*inv_sympd(B)");
 
     const Mat<eT> At = trans(X.A);
 
@@ -113,20 +129,20 @@ inline void glue_times_redirect2_helper<true>::apply(Mat<typename T1::elem_type>
 
     Mat<eT> B = B_strip.M;
 
-    arma_debug_check((B.is_square() == false),
-                     "inv_sympd(): given matrix must be square sized");
+    arma_conform_check((B.is_square() == false),
+                       "inv_sympd(): given matrix must be square sized");
 
-    if ((arma_config::debug) && (auxlib::rudimentary_sym_check(B) == false)) {
+    if ((arma_config::check_conform) && (auxlib::rudimentary_sym_check(B) == false)) {
       if (is_cx<eT>::no) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not symmetric");
+        arma_warn(1, "inv_sympd(): given matrix is not symmetric");
       }
       if (is_cx<eT>::yes) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not hermitian");
+        arma_warn(1, "inv_sympd(): given matrix is not hermitian");
       }
     }
 
-    arma_debug_assert_mul_size(At.n_cols, At.n_rows, B.n_rows, B.n_cols,
-                               "matrix multiplication");
+    arma_conform_assert_mul_size(At.n_cols, At.n_rows, B.n_rows, B.n_cols,
+                                 "matrix multiplication");
 
     const bool status = auxlib::solve_sympd_fast(out, B, At);
 
@@ -150,7 +166,7 @@ template <typename T1, typename T2, typename T3>
 inline void glue_times_redirect3_helper<do_inv_detect>::apply(
     Mat<typename T1::elem_type>& out,
     const Glue<Glue<T1, T2, glue_times>, T3, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -165,8 +181,8 @@ inline void glue_times_redirect3_helper<do_inv_detect>::apply(
   const typename partial_unwrap<T2>::stored_type& B = tmp2.M;
   const typename partial_unwrap<T3>::stored_type& C = tmp3.M;
 
-  const bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times ||
-                         partial_unwrap<T3>::do_times;
+  constexpr bool use_alpha = partial_unwrap<T1>::do_times ||
+                             partial_unwrap<T2>::do_times || partial_unwrap<T3>::do_times;
   const eT alpha = use_alpha ? (tmp1.get_val() * tmp2.get_val() * tmp3.get_val()) : eT(0);
 
   const bool alias = tmp1.is_alias(out) || tmp2.is_alias(out) || tmp3.is_alias(out);
@@ -192,7 +208,7 @@ template <typename T1, typename T2, typename T3>
 inline void glue_times_redirect3_helper<true>::apply(
     Mat<typename T1::elem_type>& out,
     const Glue<Glue<T1, T2, glue_times>, T3, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -200,14 +216,14 @@ inline void glue_times_redirect3_helper<true>::apply(
       (strip_inv<T1>::do_inv_gen || strip_inv<T1>::do_inv_spd)) {
     // replace inv(A)*B*C with solve(A,B*C);
 
-    arma_extra_debug_print("glue_times_redirect<3>::apply(): detected inv(A)*B*C");
+    arma_debug_print("glue_times_redirect<3>::apply(): detected inv(A)*B*C");
 
     const strip_inv<T1> A_strip(X.A.A);
 
     Mat<eT> A = A_strip.M;
 
-    arma_debug_check((A.is_square() == false),
-                     "inv(): given matrix must be square sized");
+    arma_conform_check((A.is_square() == false),
+                       "inv(): given matrix must be square sized");
 
     const partial_unwrap<T2> tmp2(X.A.B);
     const partial_unwrap<T3> tmp3(X.B);
@@ -215,7 +231,8 @@ inline void glue_times_redirect3_helper<true>::apply(
     const typename partial_unwrap<T2>::stored_type& B = tmp2.M;
     const typename partial_unwrap<T3>::stored_type& C = tmp3.M;
 
-    const bool use_alpha = partial_unwrap<T2>::do_times || partial_unwrap<T3>::do_times;
+    constexpr bool use_alpha =
+        partial_unwrap<T2>::do_times || partial_unwrap<T3>::do_times;
     const eT alpha = use_alpha ? (tmp2.get_val() * tmp3.get_val()) : eT(0);
 
     Mat<eT> BC;
@@ -224,15 +241,15 @@ inline void glue_times_redirect3_helper<true>::apply(
                       (partial_unwrap<T2>::do_times || partial_unwrap<T3>::do_times)>(
         BC, B, C, alpha);
 
-    arma_debug_assert_mul_size(A, BC, "matrix multiplication");
+    arma_conform_assert_mul_size(A, BC, "matrix multiplication");
 
-    if ((strip_inv<T1>::do_inv_spd) && (arma_config::debug) &&
+    if ((strip_inv<T1>::do_inv_spd) && (arma_config::check_conform) &&
         (auxlib::rudimentary_sym_check(A) == false)) {
       if (is_cx<eT>::no) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not symmetric");
+        arma_warn(1, "inv_sympd(): given matrix is not symmetric");
       }
       if (is_cx<eT>::yes) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not hermitian");
+        arma_warn(1, "inv_sympd(): given matrix is not hermitian");
       }
     }
 
@@ -254,27 +271,27 @@ inline void glue_times_redirect3_helper<true>::apply(
       (strip_inv<T2>::do_inv_gen || strip_inv<T2>::do_inv_spd)) {
     // replace A*inv(B)*C with A*solve(B,C)
 
-    arma_extra_debug_print("glue_times_redirect<3>::apply(): detected A*inv(B)*C");
+    arma_debug_print("glue_times_redirect<3>::apply(): detected A*inv(B)*C");
 
     const strip_inv<T2> B_strip(X.A.B);
 
     Mat<eT> B = B_strip.M;
 
-    arma_debug_check((B.is_square() == false),
-                     "inv(): given matrix must be square sized");
+    arma_conform_check((B.is_square() == false),
+                       "inv(): given matrix must be square sized");
 
     const unwrap<T3> C_tmp(X.B);
     const Mat<eT>& C = C_tmp.M;
 
-    arma_debug_assert_mul_size(B, C, "matrix multiplication");
+    arma_conform_assert_mul_size(B, C, "matrix multiplication");
 
-    if ((strip_inv<T2>::do_inv_spd) && (arma_config::debug) &&
+    if ((strip_inv<T2>::do_inv_spd) && (arma_config::check_conform) &&
         (auxlib::rudimentary_sym_check(B) == false)) {
       if (is_cx<eT>::no) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not symmetric");
+        arma_warn(1, "inv_sympd(): given matrix is not symmetric");
       }
       if (is_cx<eT>::yes) {
-        arma_debug_warn_level(1, "inv_sympd(): given matrix is not hermitian");
+        arma_warn(1, "inv_sympd(): given matrix is not hermitian");
       }
     }
 
@@ -296,7 +313,7 @@ inline void glue_times_redirect3_helper<true>::apply(
 
     const typename partial_unwrap_check<T1>::stored_type& A = tmp1.M;
 
-    const bool use_alpha = partial_unwrap_check<T1>::do_times;
+    constexpr bool use_alpha = partial_unwrap_check<T1>::do_times;
     const eT alpha = use_alpha ? tmp1.get_val() : eT(0);
 
     glue_times::apply<eT, partial_unwrap_check<T1>::do_trans, false,
@@ -312,7 +329,7 @@ template <uword N>
 template <typename T1, typename T2>
 inline void glue_times_redirect<N>::apply(Mat<typename T1::elem_type>& out,
                                           const Glue<T1, T2, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -322,7 +339,7 @@ inline void glue_times_redirect<N>::apply(Mat<typename T1::elem_type>& out,
   const typename partial_unwrap<T1>::stored_type& A = tmp1.M;
   const typename partial_unwrap<T2>::stored_type& B = tmp2.M;
 
-  const bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
+  constexpr bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times;
   const eT alpha = use_alpha ? (tmp1.get_val() * tmp2.get_val()) : eT(0);
 
   const bool alias = tmp1.is_alias(out) || tmp2.is_alias(out);
@@ -345,7 +362,7 @@ inline void glue_times_redirect<N>::apply(Mat<typename T1::elem_type>& out,
 template <typename T1, typename T2>
 inline void glue_times_redirect<2>::apply(Mat<typename T1::elem_type>& out,
                                           const Glue<T1, T2, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -356,7 +373,7 @@ template <typename T1, typename T2, typename T3>
 inline void glue_times_redirect<3>::apply(
     Mat<typename T1::elem_type>& out,
     const Glue<Glue<T1, T2, glue_times>, T3, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -367,7 +384,7 @@ template <typename T1, typename T2, typename T3, typename T4>
 inline void glue_times_redirect<4>::apply(
     Mat<typename T1::elem_type>& out,
     const Glue<Glue<Glue<T1, T2, glue_times>, T3, glue_times>, T4, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -384,8 +401,9 @@ inline void glue_times_redirect<4>::apply(
   const typename partial_unwrap<T3>::stored_type& C = tmp3.M;
   const typename partial_unwrap<T4>::stored_type& D = tmp4.M;
 
-  const bool use_alpha = partial_unwrap<T1>::do_times || partial_unwrap<T2>::do_times ||
-                         partial_unwrap<T3>::do_times || partial_unwrap<T4>::do_times;
+  constexpr bool use_alpha = partial_unwrap<T1>::do_times ||
+                             partial_unwrap<T2>::do_times ||
+                             partial_unwrap<T3>::do_times || partial_unwrap<T4>::do_times;
   const eT alpha =
       use_alpha ? (tmp1.get_val() * tmp2.get_val() * tmp3.get_val() * tmp4.get_val())
                 : eT(0);
@@ -415,18 +433,18 @@ inline void glue_times_redirect<4>::apply(
 template <typename T1, typename T2>
 inline void glue_times::apply(Mat<typename T1::elem_type>& out,
                               const Glue<T1, T2, glue_times>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   constexpr uword N_mat = 1 + depth_lhs<glue_times, Glue<T1, T2, glue_times> >::num;
 
-  arma_extra_debug_print(arma_str::format("N_mat = %u") % N_mat);
+  arma_debug_print(arma_str::format("N_mat: %u") % N_mat);
 
   glue_times_redirect<N_mat>::apply(out, X);
 }
 
 template <typename T1>
 inline void glue_times::apply_inplace(Mat<typename T1::elem_type>& out, const T1& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   out = out * X;
 }
@@ -435,7 +453,7 @@ template <typename T1, typename T2>
 inline void glue_times::apply_inplace_plus(Mat<typename T1::elem_type>& out,
                                            const Glue<T1, T2, glue_times>& X,
                                            const sword sign) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
   typedef typename get_pod_type<eT>::result T;
@@ -464,8 +482,8 @@ inline void glue_times::apply_inplace_plus(Mat<typename T1::elem_type>& out,
   const TA& A = tmp1.M;
   const TB& B = tmp2.M;
 
-  const bool do_trans_A = partial_unwrap_check<T1>::do_trans;
-  const bool do_trans_B = partial_unwrap_check<T2>::do_trans;
+  constexpr bool do_trans_A = partial_unwrap_check<T1>::do_trans;
+  constexpr bool do_trans_B = partial_unwrap_check<T2>::do_trans;
 
   const bool use_alpha = partial_unwrap_check<T1>::do_times ||
                          partial_unwrap_check<T2>::do_times || (sign < sword(0));
@@ -474,15 +492,15 @@ inline void glue_times::apply_inplace_plus(Mat<typename T1::elem_type>& out,
       use_alpha ? (tmp1.get_val() * tmp2.get_val() * ((sign > sword(0)) ? eT(1) : eT(-1)))
                 : eT(0);
 
-  arma_debug_assert_mul_size(A, B, do_trans_A, do_trans_B, "matrix multiplication");
+  arma_conform_assert_mul_size(A, B, do_trans_A, do_trans_B, "matrix multiplication");
 
   const uword result_n_rows =
       (do_trans_A == false) ? (TA::is_row ? 1 : A.n_rows) : (TA::is_col ? 1 : A.n_cols);
   const uword result_n_cols =
       (do_trans_B == false) ? (TB::is_col ? 1 : B.n_cols) : (TB::is_row ? 1 : B.n_rows);
 
-  arma_debug_assert_same_size(out.n_rows, out.n_cols, result_n_rows, result_n_cols,
-                              ((sign > sword(0)) ? "addition" : "subtraction"));
+  arma_conform_assert_same_size(out.n_rows, out.n_cols, result_n_rows, result_n_cols,
+                                ((sign > sword(0)) ? "addition" : "subtraction"));
 
   if (out.n_elem == 0) {
     return;
@@ -581,10 +599,10 @@ arma_inline uword glue_times::mul_storage_cost(const TA& A, const TB& B) {
 template <typename eT, const bool do_trans_A, const bool do_trans_B, const bool use_alpha,
           typename TA, typename TB>
 inline void glue_times::apply(Mat<eT>& out, const TA& A, const TB& B, const eT alpha) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  // arma_debug_assert_mul_size(A, B, do_trans_A, do_trans_B, "matrix multiplication");
-  arma_debug_assert_trans_mul_size<do_trans_A, do_trans_B>(
+  // arma_conform_assert_mul_size(A, B, do_trans_A, do_trans_B, "matrix multiplication");
+  arma_conform_assert_trans_mul_size<do_trans_A, do_trans_B>(
       A.n_rows, A.n_cols, B.n_rows, B.n_cols, "matrix multiplication");
 
   const uword final_n_rows =
@@ -683,7 +701,7 @@ template <typename eT, const bool do_trans_A, const bool do_trans_B,
           typename TC>
 inline void glue_times::apply(Mat<eT>& out, const TA& A, const TB& B, const TC& C,
                               const eT alpha) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp;
 
@@ -710,7 +728,7 @@ template <typename eT, const bool do_trans_A, const bool do_trans_B,
           typename TB, typename TC, typename TD>
 inline void glue_times::apply(Mat<eT>& out, const TA& A, const TB& B, const TC& C,
                               const TD& D, const eT alpha) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp;
 
@@ -742,7 +760,7 @@ inline void glue_times::apply(Mat<eT>& out, const TA& A, const TB& B, const TC&
 template <typename T1, typename T2>
 inline void glue_times_diag::apply(Mat<typename T1::elem_type>& actual_out,
                                    const Glue<T1, T2, glue_times_diag>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::elem_type eT;
 
@@ -754,7 +772,7 @@ inline void glue_times_diag::apply(Mat<typename T1::elem_type>& actual_out,
 
   if ((strip_diagmat<T1>::do_diagmat == true) &&
       (strip_diagmat<T2>::do_diagmat == false)) {
-    arma_extra_debug_print("glue_times_diag::apply(): diagmat(A) * B");
+    arma_debug_print("glue_times_diag::apply(): diagmat(A) * B");
 
     const diagmat_proxy<T1_stripped> A(S1.M);
 
@@ -768,13 +786,13 @@ inline void glue_times_diag::apply(Mat<typename T1::elem_type>& actual_out,
     const uword B_n_rows = B.n_rows;
     const uword B_n_cols = B.n_cols;
 
-    arma_debug_assert_mul_size(A_n_rows, A_n_cols, B_n_rows, B_n_cols,
-                               "matrix multiplication");
+    arma_conform_assert_mul_size(A_n_rows, A_n_cols, B_n_rows, B_n_cols,
+                                 "matrix multiplication");
 
     const bool is_alias = (A.is_alias(actual_out) || UB.is_alias(actual_out));
 
     if (is_alias) {
-      arma_extra_debug_print("glue_times_diag::apply(): aliasing detected");
+      arma_debug_print("glue_times_diag::apply(): aliasing detected");
     }
 
     Mat<eT> tmp;
@@ -796,7 +814,7 @@ inline void glue_times_diag::apply(Mat<typename T1::elem_type>& actual_out,
     }
   } else if ((strip_diagmat<T1>::do_diagmat == false) &&
              (strip_diagmat<T2>::do_diagmat == true)) {
-    arma_extra_debug_print("glue_times_diag::apply(): A * diagmat(B)");
+    arma_debug_print("glue_times_diag::apply(): A * diagmat(B)");
 
     const quasi_unwrap<T1> UA(X.A);
     const Mat<eT>& A = UA.M;
@@ -810,13 +828,13 @@ inline void glue_times_diag::apply(Mat<typename T1::elem_type>& actual_out,
     const uword B_n_cols = B.n_cols;
     const uword B_length = (std::min)(B_n_rows, B_n_cols);
 
-    arma_debug_assert_mul_size(A_n_rows, A_n_cols, B_n_rows, B_n_cols,
-                               "matrix multiplication");
+    arma_conform_assert_mul_size(A_n_rows, A_n_cols, B_n_rows, B_n_cols,
+                                 "matrix multiplication");
 
     const bool is_alias = (UA.is_alias(actual_out) || B.is_alias(actual_out));
 
     if (is_alias) {
-      arma_extra_debug_print("glue_times_diag::apply(): aliasing detected");
+      arma_debug_print("glue_times_diag::apply(): aliasing detected");
     }
 
     Mat<eT> tmp;
@@ -840,18 +858,18 @@ inline void glue_times_diag::apply(Mat<typename T1::elem_type>& actual_out,
     }
   } else if ((strip_diagmat<T1>::do_diagmat == true) &&
              (strip_diagmat<T2>::do_diagmat == true)) {
-    arma_extra_debug_print("glue_times_diag::apply(): diagmat(A) * diagmat(B)");
+    arma_debug_print("glue_times_diag::apply(): diagmat(A) * diagmat(B)");
 
     const diagmat_proxy<T1_stripped> A(S1.M);
     const diagmat_proxy<T2_stripped> B(S2.M);
 
-    arma_debug_assert_mul_size(A.n_rows, A.n_cols, B.n_rows, B.n_cols,
-                               "matrix multiplication");
+    arma_conform_assert_mul_size(A.n_rows, A.n_cols, B.n_rows, B.n_cols,
+                                 "matrix multiplication");
 
     const bool is_alias = (A.is_alias(actual_out) || B.is_alias(actual_out));
 
     if (is_alias) {
-      arma_extra_debug_print("glue_times_diag::apply(): aliasing detected");
+      arma_debug_print("glue_times_diag::apply(): aliasing detected");
     }
 
     Mat<eT> tmp;
