@@ -22,7 +22,7 @@ namespace gmm_priv {
 
 template <typename eT>
 inline gmm_diag<eT>::~gmm_diag() {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 
   arma_type_check(((is_same_type<eT, float>::value == false) &&
                    (is_same_type<eT, double>::value == false)));
@@ -30,19 +30,19 @@ inline gmm_diag<eT>::~gmm_diag() {
 
 template <typename eT>
 inline gmm_diag<eT>::gmm_diag() {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 }
 
 template <typename eT>
 inline gmm_diag<eT>::gmm_diag(const gmm_diag<eT>& x) {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 
   init(x);
 }
 
 template <typename eT>
 inline gmm_diag<eT>& gmm_diag<eT>::operator=(const gmm_diag<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   init(x);
 
@@ -51,14 +51,14 @@ inline gmm_diag<eT>& gmm_diag<eT>::operator=(const gmm_diag<eT>& x) {
 
 template <typename eT>
 inline gmm_diag<eT>::gmm_diag(const gmm_full<eT>& x) {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 
   init(x);
 }
 
 template <typename eT>
 inline gmm_diag<eT>& gmm_diag<eT>::operator=(const gmm_full<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   init(x);
 
@@ -67,21 +67,21 @@ inline gmm_diag<eT>& gmm_diag<eT>::operator=(const gmm_full<eT>& x) {
 
 template <typename eT>
 inline gmm_diag<eT>::gmm_diag(const uword in_n_dims, const uword in_n_gaus) {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 
   init(in_n_dims, in_n_gaus);
 }
 
 template <typename eT>
 inline void gmm_diag<eT>::reset() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   init(0, 0);
 }
 
 template <typename eT>
 inline void gmm_diag<eT>::reset(const uword in_n_dims, const uword in_n_gaus) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   init(in_n_dims, in_n_gaus);
 }
@@ -91,7 +91,7 @@ template <typename T1, typename T2, typename T3>
 inline void gmm_diag<eT>::set_params(const Base<eT, T1>& in_means_expr,
                                      const Base<eT, T2>& in_dcovs_expr,
                                      const Base<eT, T3>& in_hefts_expr) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap<T1> tmp1(in_means_expr.get_ref());
   const unwrap<T2> tmp2(in_dcovs_expr.get_ref());
@@ -101,27 +101,27 @@ inline void gmm_diag<eT>::set_params(const Base<eT, T1>& in_means_expr,
   const Mat<eT>& in_dcovs = tmp2.M;
   const Mat<eT>& in_hefts = tmp3.M;
 
-  arma_debug_check(
+  arma_conform_check(
       (arma::size(in_means) != arma::size(in_dcovs)) ||
           (in_hefts.n_cols != in_means.n_cols) || (in_hefts.n_rows != 1),
       "gmm_diag::set_params(): given parameters have inconsistent and/or wrong sizes");
 
-  arma_debug_check((in_means.internal_has_nonfinite()),
-                   "gmm_diag::set_params(): given means have non-finite values");
-  arma_debug_check((in_dcovs.internal_has_nonfinite()),
-                   "gmm_diag::set_params(): given dcovs have non-finite values");
-  arma_debug_check((in_hefts.internal_has_nonfinite()),
-                   "gmm_diag::set_params(): given hefts have non-finite values");
+  arma_conform_check((in_means.internal_has_nonfinite()),
+                     "gmm_diag::set_params(): given means have non-finite values");
+  arma_conform_check((in_dcovs.internal_has_nonfinite()),
+                     "gmm_diag::set_params(): given dcovs have non-finite values");
+  arma_conform_check((in_hefts.internal_has_nonfinite()),
+                     "gmm_diag::set_params(): given hefts have non-finite values");
 
-  arma_debug_check((any(vectorise(in_dcovs) <= eT(0))),
-                   "gmm_diag::set_params(): given dcovs have negative or zero values");
-  arma_debug_check((any(vectorise(in_hefts) < eT(0))),
-                   "gmm_diag::set_params(): given hefts have negative values");
+  arma_conform_check((any(vectorise(in_dcovs) <= eT(0))),
+                     "gmm_diag::set_params(): given dcovs have negative or zero values");
+  arma_conform_check((any(vectorise(in_hefts) < eT(0))),
+                     "gmm_diag::set_params(): given hefts have negative values");
 
   const eT s = accu(in_hefts);
 
-  arma_debug_check(((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))),
-                   "gmm_diag::set_params(): sum of given hefts is not 1");
+  arma_conform_check(((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))),
+                     "gmm_diag::set_params(): sum of given hefts is not 1");
 
   access::rw(means) = in_means;
   access::rw(dcovs) = in_dcovs;
@@ -133,16 +133,16 @@ inline void gmm_diag<eT>::set_params(const Base<eT, T1>& in_means_expr,
 template <typename eT>
 template <typename T1>
 inline void gmm_diag<eT>::set_means(const Base<eT, T1>& in_means_expr) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap<T1> tmp(in_means_expr.get_ref());
 
   const Mat<eT>& in_means = tmp.M;
 
-  arma_debug_check((arma::size(in_means) != arma::size(means)),
-                   "gmm_diag::set_means(): given means have incompatible size");
-  arma_debug_check((in_means.internal_has_nonfinite()),
-                   "gmm_diag::set_means(): given means have non-finite values");
+  arma_conform_check((arma::size(in_means) != arma::size(means)),
+                     "gmm_diag::set_means(): given means have incompatible size");
+  arma_conform_check((in_means.internal_has_nonfinite()),
+                     "gmm_diag::set_means(): given means have non-finite values");
 
   access::rw(means) = in_means;
 }
@@ -150,18 +150,18 @@ inline void gmm_diag<eT>::set_means(const Base<eT, T1>& in_means_expr) {
 template <typename eT>
 template <typename T1>
 inline void gmm_diag<eT>::set_dcovs(const Base<eT, T1>& in_dcovs_expr) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap<T1> tmp(in_dcovs_expr.get_ref());
 
   const Mat<eT>& in_dcovs = tmp.M;
 
-  arma_debug_check((arma::size(in_dcovs) != arma::size(dcovs)),
-                   "gmm_diag::set_dcovs(): given dcovs have incompatible size");
-  arma_debug_check((in_dcovs.internal_has_nonfinite()),
-                   "gmm_diag::set_dcovs(): given dcovs have non-finite values");
-  arma_debug_check((any(vectorise(in_dcovs) <= eT(0))),
-                   "gmm_diag::set_dcovs(): given dcovs have negative or zero values");
+  arma_conform_check((arma::size(in_dcovs) != arma::size(dcovs)),
+                     "gmm_diag::set_dcovs(): given dcovs have incompatible size");
+  arma_conform_check((in_dcovs.internal_has_nonfinite()),
+                     "gmm_diag::set_dcovs(): given dcovs have non-finite values");
+  arma_conform_check((any(vectorise(in_dcovs) <= eT(0))),
+                     "gmm_diag::set_dcovs(): given dcovs have negative or zero values");
 
   access::rw(dcovs) = in_dcovs;
 
@@ -171,23 +171,23 @@ inline void gmm_diag<eT>::set_dcovs(const Base<eT, T1>& in_dcovs_expr) {
 template <typename eT>
 template <typename T1>
 inline void gmm_diag<eT>::set_hefts(const Base<eT, T1>& in_hefts_expr) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap<T1> tmp(in_hefts_expr.get_ref());
 
   const Mat<eT>& in_hefts = tmp.M;
 
-  arma_debug_check((arma::size(in_hefts) != arma::size(hefts)),
-                   "gmm_diag::set_hefts(): given hefts have incompatible size");
-  arma_debug_check((in_hefts.internal_has_nonfinite()),
-                   "gmm_diag::set_hefts(): given hefts have non-finite values");
-  arma_debug_check((any(vectorise(in_hefts) < eT(0))),
-                   "gmm_diag::set_hefts(): given hefts have negative values");
+  arma_conform_check((arma::size(in_hefts) != arma::size(hefts)),
+                     "gmm_diag::set_hefts(): given hefts have incompatible size");
+  arma_conform_check((in_hefts.internal_has_nonfinite()),
+                     "gmm_diag::set_hefts(): given hefts have non-finite values");
+  arma_conform_check((any(vectorise(in_hefts) < eT(0))),
+                     "gmm_diag::set_hefts(): given hefts have negative values");
 
   const eT s = accu(in_hefts);
 
-  arma_debug_check(((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))),
-                   "gmm_diag::set_hefts(): sum of given hefts is not 1");
+  arma_conform_check(((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))),
+                     "gmm_diag::set_hefts(): sum of given hefts is not 1");
 
   // make sure all hefts are positive and non-zero
 
@@ -215,7 +215,7 @@ inline uword gmm_diag<eT>::n_gaus() const {
 
 template <typename eT>
 inline bool gmm_diag<eT>::load(const std::string name) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Cube<eT> Q;
 
@@ -223,8 +223,7 @@ inline bool gmm_diag<eT>::load(const std::string name) {
 
   if ((status == false) || (Q.n_slices != 2)) {
     reset();
-    arma_debug_warn_level(
-        3, "gmm_diag::load(): problem with loading or incompatible format");
+    arma_warn(3, "gmm_diag::load(): problem with loading or incompatible format");
     return false;
   }
 
@@ -244,7 +243,7 @@ inline bool gmm_diag<eT>::load(const std::string name) {
 
 template <typename eT>
 inline bool gmm_diag<eT>::save(const std::string name) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Cube<eT> Q(means.n_rows + 1, means.n_cols, 2, arma_nozeros_indicator());
 
@@ -263,7 +262,7 @@ inline bool gmm_diag<eT>::save(const std::string name) const {
 
 template <typename eT>
 inline Col<eT> gmm_diag<eT>::generate() const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -294,7 +293,7 @@ inline Col<eT> gmm_diag<eT>::generate() const {
 
 template <typename eT>
 inline Mat<eT> gmm_diag<eT>::generate(const uword N_vec) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -337,14 +336,14 @@ inline eT gmm_diag<eT>::log_p(
     const T1& expr, const gmm_empty_arg& junk1,
     typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value ==
                                                       true))>::result* junk2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
 
   const quasi_unwrap<T1> tmp(expr);
 
-  arma_debug_check((tmp.M.n_rows != means.n_rows),
-                   "gmm_diag::log_p(): incompatible dimensions");
+  arma_conform_check((tmp.M.n_rows != means.n_rows),
+                     "gmm_diag::log_p(): incompatible dimensions");
 
   return internal_scalar_log_p(tmp.M.memptr());
 }
@@ -355,16 +354,16 @@ inline eT gmm_diag<eT>::log_p(
     const T1& expr, const uword gaus_id,
     typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value ==
                                                       true))>::result* junk2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk2);
 
   const quasi_unwrap<T1> tmp(expr);
 
-  arma_debug_check((tmp.M.n_rows != means.n_rows),
-                   "gmm_diag::log_p(): incompatible dimensions");
+  arma_conform_check((tmp.M.n_rows != means.n_rows),
+                     "gmm_diag::log_p(): incompatible dimensions");
 
-  arma_debug_check((gaus_id >= means.n_cols),
-                   "gmm_diag::log_p(): specified gaussian is out of range");
+  arma_conform_check((gaus_id >= means.n_cols),
+                     "gmm_diag::log_p(): specified gaussian is out of range");
 
   return internal_scalar_log_p(tmp.M.memptr(), gaus_id);
 }
@@ -375,7 +374,7 @@ inline Row<eT> gmm_diag<eT>::log_p(
     const T1& expr, const gmm_empty_arg& junk1,
     typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value ==
                                                       false))>::result* junk2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
 
@@ -392,7 +391,7 @@ inline Row<eT> gmm_diag<eT>::log_p(
     const T1& expr, const uword gaus_id,
     typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value ==
                                                       false))>::result* junk2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk2);
 
   const quasi_unwrap<T1> tmp(expr);
@@ -405,7 +404,7 @@ inline Row<eT> gmm_diag<eT>::log_p(
 template <typename eT>
 template <typename T1>
 inline eT gmm_diag<eT>::sum_log_p(const Base<eT, T1>& expr) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const quasi_unwrap<T1> tmp(expr.get_ref());
 
@@ -417,7 +416,7 @@ inline eT gmm_diag<eT>::sum_log_p(const Base<eT, T1>& expr) const {
 template <typename eT>
 template <typename T1>
 inline eT gmm_diag<eT>::sum_log_p(const Base<eT, T1>& expr, const uword gaus_id) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const quasi_unwrap<T1> tmp(expr.get_ref());
 
@@ -429,7 +428,7 @@ inline eT gmm_diag<eT>::sum_log_p(const Base<eT, T1>& expr, const uword gaus_id)
 template <typename eT>
 template <typename T1>
 inline eT gmm_diag<eT>::avg_log_p(const Base<eT, T1>& expr) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const quasi_unwrap<T1> tmp(expr.get_ref());
 
@@ -441,7 +440,7 @@ inline eT gmm_diag<eT>::avg_log_p(const Base<eT, T1>& expr) const {
 template <typename eT>
 template <typename T1>
 inline eT gmm_diag<eT>::avg_log_p(const Base<eT, T1>& expr, const uword gaus_id) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const quasi_unwrap<T1> tmp(expr.get_ref());
 
@@ -456,7 +455,7 @@ inline uword gmm_diag<eT>::assign(
     const T1& expr, const gmm_dist_mode& dist,
     typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value ==
                                                       true))>::result* junk) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
 
   const quasi_unwrap<T1> tmp(expr);
@@ -472,7 +471,7 @@ inline urowvec gmm_diag<eT>::assign(
     const T1& expr, const gmm_dist_mode& dist,
     typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value ==
                                                       false))>::result* junk) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
 
   urowvec out;
@@ -490,16 +489,16 @@ template <typename eT>
 template <typename T1>
 inline urowvec gmm_diag<eT>::raw_hist(const Base<eT, T1>& expr,
                                       const gmm_dist_mode& dist_mode) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap<T1> tmp(expr.get_ref());
   const Mat<eT>& X = tmp.M;
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::raw_hist(): incompatible dimensions");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::raw_hist(): incompatible dimensions");
 
-  arma_debug_check(((dist_mode != eucl_dist) && (dist_mode != prob_dist)),
-                   "gmm_diag::raw_hist(): unsupported distance mode");
+  arma_conform_check(((dist_mode != eucl_dist) && (dist_mode != prob_dist)),
+                     "gmm_diag::raw_hist(): unsupported distance mode");
 
   urowvec hist;
 
@@ -512,16 +511,16 @@ template <typename eT>
 template <typename T1>
 inline Row<eT> gmm_diag<eT>::norm_hist(const Base<eT, T1>& expr,
                                        const gmm_dist_mode& dist_mode) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap<T1> tmp(expr.get_ref());
   const Mat<eT>& X = tmp.M;
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::norm_hist(): incompatible dimensions");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::norm_hist(): incompatible dimensions");
 
-  arma_debug_check(((dist_mode != eucl_dist) && (dist_mode != prob_dist)),
-                   "gmm_diag::norm_hist(): unsupported distance mode");
+  arma_conform_check(((dist_mode != eucl_dist) && (dist_mode != prob_dist)),
+                     "gmm_diag::norm_hist(): unsupported distance mode");
 
   urowvec hist;
 
@@ -557,7 +556,7 @@ inline bool gmm_diag<eT>::learn(const Base<eT, T1>& data, const uword N_gaus,
                                 const gmm_seed_mode& seed_mode, const uword km_iter,
                                 const uword em_iter, const eT var_floor,
                                 const bool print_mode) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool dist_mode_ok = (dist_mode == eucl_dist) || (dist_mode == maha_dist);
 
@@ -566,20 +565,21 @@ inline bool gmm_diag<eT>::learn(const Base<eT, T1>& data, const uword N_gaus,
                             (seed_mode == static_spread) ||
                             (seed_mode == random_subset) || (seed_mode == random_spread);
 
-  arma_debug_check((dist_mode_ok == false),
-                   "gmm_diag::learn(): dist_mode must be eucl_dist or maha_dist");
-  arma_debug_check((seed_mode_ok == false), "gmm_diag::learn(): unknown seed_mode");
-  arma_debug_check((var_floor < eT(0)), "gmm_diag::learn(): variance floor is negative");
+  arma_conform_check((dist_mode_ok == false),
+                     "gmm_diag::learn(): dist_mode must be eucl_dist or maha_dist");
+  arma_conform_check((seed_mode_ok == false), "gmm_diag::learn(): unknown seed_mode");
+  arma_conform_check((var_floor < eT(0)),
+                     "gmm_diag::learn(): variance floor is negative");
 
   const unwrap<T1> tmp_X(data.get_ref());
   const Mat<eT>& X = tmp_X.M;
 
   if (X.is_empty()) {
-    arma_debug_warn_level(3, "gmm_diag::learn(): given matrix is empty");
+    arma_warn(3, "gmm_diag::learn(): given matrix is empty");
     return false;
   }
   if (X.internal_has_nonfinite()) {
-    arma_debug_warn_level(3, "gmm_diag::learn(): given matrix has non-finite values");
+    arma_warn(3, "gmm_diag::learn(): given matrix has non-finite values");
     return false;
   }
 
@@ -609,19 +609,19 @@ inline bool gmm_diag<eT>::learn(const Base<eT, T1>& data, const uword N_gaus,
 
   if (seed_mode == keep_existing) {
     if (means.is_empty()) {
-      arma_debug_warn_level(3, "gmm_diag::learn(): no existing means");
+      arma_warn(3, "gmm_diag::learn(): no existing means");
       return false;
     }
     if (X.n_rows != means.n_rows) {
-      arma_debug_warn_level(3, "gmm_diag::learn(): dimensionality mismatch");
+      arma_warn(3, "gmm_diag::learn(): dimensionality mismatch");
       return false;
     }
 
     // TODO: also check for number of vectors?
   } else {
     if (X.n_cols < N_gaus) {
-      arma_debug_warn_level(
-          3, "gmm_diag::learn(): number of vectors is less than number of gaussians");
+      arma_warn(3,
+                "gmm_diag::learn(): number of vectors is less than number of gaussians");
       return false;
     }
 
@@ -655,9 +655,9 @@ inline bool gmm_diag<eT>::learn(const Base<eT, T1>& data, const uword N_gaus,
     stream_state.restore(get_cout_stream());
 
     if (status == false) {
-      arma_debug_warn_level(3,
-                            "gmm_diag::learn(): k-means algorithm failed; not enough "
-                            "data, or too many gaussians requested");
+      arma_warn(3,
+                "gmm_diag::learn(): k-means algorithm failed; not enough data, or too "
+                "many gaussians requested");
       init(orig);
       return false;
     }
@@ -691,7 +691,7 @@ inline bool gmm_diag<eT>::learn(const Base<eT, T1>& data, const uword N_gaus,
     stream_state.restore(get_cout_stream());
 
     if (status == false) {
-      arma_debug_warn_level(3, "gmm_diag::learn(): EM algorithm failed");
+      arma_warn(3, "gmm_diag::learn(): EM algorithm failed");
       init(orig);
       return false;
     }
@@ -710,24 +710,24 @@ inline bool gmm_diag<eT>::kmeans_wrapper(Mat<eT>& user_means, const Base<eT, T1>
                                          const uword N_gaus,
                                          const gmm_seed_mode& seed_mode,
                                          const uword km_iter, const bool print_mode) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool seed_mode_ok = (seed_mode == keep_existing) ||
                             (seed_mode == static_subset) ||
                             (seed_mode == static_spread) ||
                             (seed_mode == random_subset) || (seed_mode == random_spread);
 
-  arma_debug_check((seed_mode_ok == false), "kmeans(): unknown seed_mode");
+  arma_conform_check((seed_mode_ok == false), "kmeans(): unknown seed_mode");
 
   const unwrap<T1> tmp_X(data.get_ref());
   const Mat<eT>& X = tmp_X.M;
 
   if (X.is_empty()) {
-    arma_debug_warn_level(3, "kmeans(): given matrix is empty");
+    arma_warn(3, "kmeans(): given matrix is empty");
     return false;
   }
   if (X.internal_has_nonfinite()) {
-    arma_debug_warn_level(3, "kmeans(): given matrix has non-finite values");
+    arma_warn(3, "kmeans(): given matrix has non-finite values");
     return false;
   }
 
@@ -742,19 +742,18 @@ inline bool gmm_diag<eT>::kmeans_wrapper(Mat<eT>& user_means, const Base<eT, T1>
     access::rw(means) = user_means;
 
     if (means.is_empty()) {
-      arma_debug_warn_level(3, "kmeans(): no existing means");
+      arma_warn(3, "kmeans(): no existing means");
       return false;
     }
     if (X.n_rows != means.n_rows) {
-      arma_debug_warn_level(3, "kmeans(): dimensionality mismatch");
+      arma_warn(3, "kmeans(): dimensionality mismatch");
       return false;
     }
 
     // TODO: also check for number of vectors?
   } else {
     if (X.n_cols < N_gaus) {
-      arma_debug_warn_level(3,
-                            "kmeans(): number of vectors is less than number of means");
+      arma_warn(3, "kmeans(): number of vectors is less than number of means");
       return false;
     }
 
@@ -779,7 +778,7 @@ inline bool gmm_diag<eT>::kmeans_wrapper(Mat<eT>& user_means, const Base<eT, T1>
     stream_state.restore(get_cout_stream());
 
     if (status == false) {
-      arma_debug_warn_level(
+      arma_warn(
           3, "kmeans(): clustering failed; not enough data, or too many means requested");
       return false;
     }
@@ -794,7 +793,7 @@ inline bool gmm_diag<eT>::kmeans_wrapper(Mat<eT>& user_means, const Base<eT, T1>
 
 template <typename eT>
 inline void gmm_diag<eT>::init(const gmm_diag<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   gmm_diag<eT>& t = *this;
 
@@ -809,7 +808,7 @@ inline void gmm_diag<eT>::init(const gmm_diag<eT>& x) {
 
 template <typename eT>
 inline void gmm_diag<eT>::init(const gmm_full<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   access::rw(hefts) = x.hefts;
   access::rw(means) = x.means;
@@ -834,7 +833,7 @@ inline void gmm_diag<eT>::init(const gmm_full<eT>& x) {
 
 template <typename eT>
 inline void gmm_diag<eT>::init(const uword in_n_dims, const uword in_n_gaus) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   access::rw(means).zeros(in_n_dims, in_n_gaus);
 
@@ -849,7 +848,7 @@ inline void gmm_diag<eT>::init(const uword in_n_dims, const uword in_n_gaus) {
 
 template <typename eT>
 inline void gmm_diag<eT>::init_constants() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -899,7 +898,7 @@ inline void gmm_diag<eT>::init_constants() {
 
 template <typename eT>
 inline umat gmm_diag<eT>::internal_gen_boundaries(const uword N) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
 #if defined(ARMA_USE_OPENMP)
   const uword n_threads_avail =
@@ -941,7 +940,7 @@ inline umat gmm_diag<eT>::internal_gen_boundaries(const uword N) const {
 
 template <typename eT>
 inline eT gmm_diag<eT>::internal_scalar_log_p(const eT* x) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const eT* log_hefts_mem = log_hefts.mem;
 
@@ -964,7 +963,7 @@ inline eT gmm_diag<eT>::internal_scalar_log_p(const eT* x) const {
 
 template <typename eT>
 inline eT gmm_diag<eT>::internal_scalar_log_p(const eT* x, const uword g) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const eT* mean = means.colptr(g);
   const eT* inv_dcov = inv_dcovs.colptr(g);
@@ -998,10 +997,10 @@ inline eT gmm_diag<eT>::internal_scalar_log_p(const eT* x, const uword g) const
 
 template <typename eT>
 inline Row<eT> gmm_diag<eT>::internal_vec_log_p(const Mat<eT>& X) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::log_p(): incompatible dimensions");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::log_p(): incompatible dimensions");
 
   const uword N = X.n_cols;
 
@@ -1043,12 +1042,12 @@ inline Row<eT> gmm_diag<eT>::internal_vec_log_p(const Mat<eT>& X) const {
 template <typename eT>
 inline Row<eT> gmm_diag<eT>::internal_vec_log_p(const Mat<eT>& X,
                                                 const uword gaus_id) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::log_p(): incompatible dimensions");
-  arma_debug_check((gaus_id >= means.n_cols),
-                   "gmm_diag::log_p(): specified gaussian is out of range");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::log_p(): incompatible dimensions");
+  arma_conform_check((gaus_id >= means.n_cols),
+                     "gmm_diag::log_p(): specified gaussian is out of range");
 
   const uword N = X.n_cols;
 
@@ -1089,10 +1088,10 @@ inline Row<eT> gmm_diag<eT>::internal_vec_log_p(const Mat<eT>& X,
 
 template <typename eT>
 inline eT gmm_diag<eT>::internal_sum_log_p(const Mat<eT>& X) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::sum_log_p(): incompatible dimensions");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::sum_log_p(): incompatible dimensions");
 
   const uword N = X.n_cols;
 
@@ -1139,12 +1138,12 @@ inline eT gmm_diag<eT>::internal_sum_log_p(const Mat<eT>& X) const {
 
 template <typename eT>
 inline eT gmm_diag<eT>::internal_sum_log_p(const Mat<eT>& X, const uword gaus_id) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::sum_log_p(): incompatible dimensions");
-  arma_debug_check((gaus_id >= means.n_cols),
-                   "gmm_diag::sum_log_p(): specified gaussian is out of range");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::sum_log_p(): incompatible dimensions");
+  arma_conform_check((gaus_id >= means.n_cols),
+                     "gmm_diag::sum_log_p(): specified gaussian is out of range");
 
   const uword N = X.n_cols;
 
@@ -1191,10 +1190,10 @@ inline eT gmm_diag<eT>::internal_sum_log_p(const Mat<eT>& X, const uword gaus_id
 
 template <typename eT>
 inline eT gmm_diag<eT>::internal_avg_log_p(const Mat<eT>& X) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::avg_log_p(): incompatible dimensions");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::avg_log_p(): incompatible dimensions");
 
   const uword N = X.n_cols;
 
@@ -1249,12 +1248,12 @@ inline eT gmm_diag<eT>::internal_avg_log_p(const Mat<eT>& X) const {
 
 template <typename eT>
 inline eT gmm_diag<eT>::internal_avg_log_p(const Mat<eT>& X, const uword gaus_id) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((X.n_rows != means.n_rows),
-                   "gmm_diag::avg_log_p(): incompatible dimensions");
-  arma_debug_check((gaus_id >= means.n_cols),
-                   "gmm_diag::avg_log_p(): specified gaussian is out of range");
+  arma_conform_check((X.n_rows != means.n_rows),
+                     "gmm_diag::avg_log_p(): incompatible dimensions");
+  arma_conform_check((gaus_id >= means.n_cols),
+                     "gmm_diag::avg_log_p(): specified gaussian is out of range");
 
   const uword N = X.n_cols;
 
@@ -1310,13 +1309,13 @@ inline eT gmm_diag<eT>::internal_avg_log_p(const Mat<eT>& X, const uword gaus_id
 template <typename eT>
 inline uword gmm_diag<eT>::internal_scalar_assign(const Mat<eT>& X,
                                                   const gmm_dist_mode& dist_mode) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
 
-  arma_debug_check((X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions");
-  arma_debug_check((N_gaus == 0), "gmm_diag::assign(): model has no means");
+  arma_conform_check((X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions");
+  arma_conform_check((N_gaus == 0), "gmm_diag::assign(): model has no means");
 
   const eT* X_mem = X.colptr(0);
 
@@ -1351,7 +1350,7 @@ inline uword gmm_diag<eT>::internal_scalar_assign(const Mat<eT>& X,
 
     return best_g;
   } else {
-    arma_debug_check(true, "gmm_diag::assign(): unsupported distance mode");
+    arma_conform_check(true, "gmm_diag::assign(): unsupported distance mode");
   }
 
   return uword(0);
@@ -1360,12 +1359,12 @@ inline uword gmm_diag<eT>::internal_scalar_assign(const Mat<eT>& X,
 template <typename eT>
 inline void gmm_diag<eT>::internal_vec_assign(urowvec& out, const Mat<eT>& X,
                                               const gmm_dist_mode& dist_mode) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
 
-  arma_debug_check((X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions");
+  arma_conform_check((X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions");
 
   const uword X_n_cols = (N_gaus > 0) ? X.n_cols : 0;
 
@@ -1466,14 +1465,14 @@ inline void gmm_diag<eT>::internal_vec_assign(urowvec& out, const Mat<eT>& X,
     }
 #endif
   } else {
-    arma_debug_check(true, "gmm_diag::assign(): unsupported distance mode");
+    arma_conform_check(true, "gmm_diag::assign(): unsupported distance mode");
   }
 }
 
 template <typename eT>
 inline void gmm_diag<eT>::internal_raw_hist(urowvec& hist, const Mat<eT>& X,
                                             const gmm_dist_mode& dist_mode) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1614,7 +1613,7 @@ template <typename eT>
 template <uword dist_id>
 inline void gmm_diag<eT>::generate_initial_means(const Mat<eT>& X,
                                                  const gmm_seed_mode& seed_mode) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1711,7 +1710,7 @@ inline void gmm_diag<eT>::generate_initial_means(const Mat<eT>& X,
 template <typename eT>
 template <uword dist_id>
 inline void gmm_diag<eT>::generate_initial_params(const Mat<eT>& X, const eT var_floor) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1860,7 +1859,7 @@ template <typename eT>
 template <uword dist_id>
 inline bool gmm_diag<eT>::km_iterate(const Mat<eT>& X, const uword max_iter,
                                      const bool verbose, const char* signature) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (verbose) {
     get_cout_stream().unsetf(ios::showbase);
@@ -2110,7 +2109,7 @@ inline bool gmm_diag<eT>::km_iterate(const Mat<eT>& X, const uword max_iter,
 template <typename eT>
 inline bool gmm_diag<eT>::em_iterate(const Mat<eT>& X, const uword max_iter,
                                      const eT var_floor, const bool verbose) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (X.n_cols == 0) {
     return true;
@@ -2212,7 +2211,7 @@ inline void gmm_diag<eT>::em_update_params(const Mat<eT>& X, const umat& boundar
                                            field<Col<eT> >& t_acc_norm_lhoods,
                                            field<Col<eT> >& t_gaus_log_lhoods,
                                            Col<eT>& t_progress_log_lhood) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword n_threads = boundaries.n_cols;
 
@@ -2331,7 +2330,7 @@ inline void gmm_diag<eT>::em_generate_acc(const Mat<eT>& X, const uword start_in
                                           Mat<eT>& acc_dcovs, Col<eT>& acc_norm_lhoods,
                                           Col<eT>& gaus_log_lhoods,
                                           eT& progress_log_lhood) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   progress_log_lhood = eT(0);
 
@@ -2385,7 +2384,7 @@ inline void gmm_diag<eT>::em_generate_acc(const Mat<eT>& X, const uword start_in
 
 template <typename eT>
 inline void gmm_diag<eT>::em_fix_params(const eT var_floor) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
