@@ -22,7 +22,7 @@ template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_1(
     const Proxy<T1>& P,
     const typename arma_not_cx<typename T1::elem_type>::result* junk) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
 
   const bool use_direct_mem = (is_Mat<typename Proxy<T1>::stored_type>::value) ||
@@ -94,7 +94,7 @@ template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_1(
     const Proxy<T1>& P,
     const typename arma_cx_only<typename T1::elem_type>::result* junk) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
 
   typedef typename T1::elem_type eT;
@@ -144,8 +144,7 @@ inline typename T1::pod_type op_norm::vec_norm_1(
   if ((acc != T(0)) && arma_isfinite(acc)) {
     return acc;
   } else {
-    arma_extra_debug_print(
-        "op_norm::vec_norm_1(): detected possible underflow or overflow");
+    arma_debug_print("detected possible underflow or overflow");
 
     const quasi_unwrap<typename Proxy<T1>::stored_type> R(P.Q);
 
@@ -189,27 +188,37 @@ inline typename T1::pod_type op_norm::vec_norm_1(
 
 template <typename eT>
 inline eT op_norm::vec_norm_1_direct_std(const Mat<eT>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N = X.n_elem;
   const eT* A = X.memptr();
 
-  if (N < uword(32)) {
-    return op_norm::vec_norm_1_direct_mem(N, A);
-  } else {
+  eT out_val = eT(0);
+
 #if defined(ARMA_USE_ATLAS)
-    { return atlas::cblas_asum(N, A); }
-#elif defined(ARMA_USE_BLAS)
-    { return blas::asum(N, A); }
-#else
-    { return op_norm::vec_norm_1_direct_mem(N, A); }
-#endif
+  {
+    arma_debug_print("atlas::cblas_asum()");
+    out_val = atlas::cblas_asum(N, A);
   }
+#elif defined(ARMA_USE_BLAS)
+  {
+    if (has_blas_float_bug<eT>::value) {
+      out_val = op_norm::vec_norm_1_direct_mem(N, A);
+    } else {
+      arma_debug_print("blas::asum()");
+      out_val = blas::asum(N, A);
+    }
+  }
+#else
+  { out_val = op_norm::vec_norm_1_direct_mem(N, A); }
+#endif
+
+  return (out_val <= eT(0)) ? eT(0) : out_val;
 }
 
 template <typename eT>
 inline eT op_norm::vec_norm_1_direct_mem(const uword N, const eT* A) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
 #if (defined(ARMA_SIMPLE_LOOPS) || defined(__FAST_MATH__))
   {
@@ -259,7 +268,7 @@ template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_2(
     const Proxy<T1>& P,
     const typename arma_not_cx<typename T1::elem_type>::result* junk) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
 
   const bool use_direct_mem = (is_Mat<typename Proxy<T1>::stored_type>::value) ||
@@ -336,8 +345,7 @@ inline typename T1::pod_type op_norm::vec_norm_2(
   if ((sqrt_acc != T(0)) && arma_isfinite(sqrt_acc)) {
     return sqrt_acc;
   } else {
-    arma_extra_debug_print(
-        "op_norm::vec_norm_2(): detected possible underflow or overflow");
+    arma_debug_print("detected possible underflow or overflow");
 
     const quasi_unwrap<typename Proxy<T1>::stored_type> tmp(P.Q);
 
@@ -349,7 +357,7 @@ template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_2(
     const Proxy<T1>& P,
     const typename arma_cx_only<typename T1::elem_type>::result* junk) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
 
   typedef typename T1::elem_type eT;
@@ -401,8 +409,7 @@ inline typename T1::pod_type op_norm::vec_norm_2(
   if ((sqrt_acc != T(0)) && arma_isfinite(sqrt_acc)) {
     return sqrt_acc;
   } else {
-    arma_extra_debug_print(
-        "op_norm::vec_norm_2(): detected possible underflow or overflow");
+    arma_debug_print("detected possible underflow or overflow");
 
     const quasi_unwrap<typename Proxy<T1>::stored_type> R(P.Q);
 
@@ -437,30 +444,35 @@ inline typename T1::pod_type op_norm::vec_norm_2(
 
 template <typename eT>
 inline eT op_norm::vec_norm_2_direct_std(const Mat<eT>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N = X.n_elem;
   const eT* A = X.memptr();
 
-  eT result;
+  eT out_val = eT(0);
 
-  if (N < uword(32)) {
-    result = op_norm::vec_norm_2_direct_mem(N, A);
-  } else {
 #if defined(ARMA_USE_ATLAS)
-    { result = atlas::cblas_nrm2(N, A); }
-#elif defined(ARMA_USE_BLAS)
-    { result = blas::nrm2(N, A); }
-#else
-    { result = op_norm::vec_norm_2_direct_mem(N, A); }
-#endif
+  {
+    arma_debug_print("atlas::cblas_nrm2()");
+    out_val = atlas::cblas_nrm2(N, A);
   }
+#elif defined(ARMA_USE_BLAS)
+  {
+    if (has_blas_float_bug<eT>::value) {
+      out_val = op_norm::vec_norm_2_direct_mem(N, A);
+    } else {
+      arma_debug_print("blas::nrm2()");
+      out_val = blas::nrm2(N, A);
+    }
+  }
+#else
+  { out_val = op_norm::vec_norm_2_direct_mem(N, A); }
+#endif
 
-  if ((result != eT(0)) && arma_isfinite(result)) {
-    return result;
+  if ((out_val != eT(0)) && arma_isfinite(out_val)) {
+    return (out_val < eT(0)) ? eT(0) : out_val;
   } else {
-    arma_extra_debug_print(
-        "op_norm::vec_norm_2_direct_std(): detected possible underflow or overflow");
+    arma_debug_print("detected possible underflow or overflow");
 
     return op_norm::vec_norm_2_direct_robust(X);
   }
@@ -468,9 +480,9 @@ inline eT op_norm::vec_norm_2_direct_std(const Mat<eT>& X) {
 
 template <typename eT>
 inline eT op_norm::vec_norm_2_direct_mem(const uword N, const eT* A) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  eT acc;
+  eT acc = eT(0);
 
 #if (defined(ARMA_SIMPLE_LOOPS) || defined(__FAST_MATH__))
   {
@@ -524,7 +536,7 @@ inline eT op_norm::vec_norm_2_direct_mem(const uword N, const eT* A) {
 
 template <typename eT>
 inline eT op_norm::vec_norm_2_direct_robust(const Mat<eT>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const uword N = X.n_elem;
   const eT* A = X.memptr();
@@ -586,12 +598,14 @@ inline eT op_norm::vec_norm_2_direct_robust(const Mat<eT>& X) {
     acc1 += val_i * val_i;
   }
 
-  return (std::sqrt(acc1 + acc2) * max_val);
+  const eT out_val = std::sqrt(acc1 + acc2) * max_val;
+
+  return (out_val <= eT(0)) ? eT(0) : out_val;
 }
 
 template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_k(const Proxy<T1>& P, const int k) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::pod_type T;
 
@@ -626,7 +640,7 @@ inline typename T1::pod_type op_norm::vec_norm_k(const Proxy<T1>& P, const int k
 
 template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_max(const Proxy<T1>& P) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::pod_type T;
 
@@ -686,7 +700,7 @@ inline typename T1::pod_type op_norm::vec_norm_max(const Proxy<T1>& P) {
 
 template <typename T1>
 inline typename T1::pod_type op_norm::vec_norm_min(const Proxy<T1>& P) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename T1::pod_type T;
 
@@ -746,7 +760,7 @@ inline typename T1::pod_type op_norm::vec_norm_min(const Proxy<T1>& P) {
 
 template <typename eT>
 inline typename get_pod_type<eT>::result op_norm::mat_norm_1(const Mat<eT>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // TODO: this can be sped up with a dedicated implementation
   return as_scalar(max(sum(abs(X), 0), 1));
@@ -754,23 +768,26 @@ inline typename get_pod_type<eT>::result op_norm::mat_norm_1(const Mat<eT>& X) {
 
 template <typename eT>
 inline typename get_pod_type<eT>::result op_norm::mat_norm_2(const Mat<eT>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   typedef typename get_pod_type<eT>::result T;
 
   if (X.internal_has_nonfinite()) {
-    arma_debug_warn_level(1, "norm(): given matrix has non-finite elements");
+    arma_warn(1, "norm(): given matrix has non-finite elements");
   }
 
   Col<T> S;
+
   svd(S, X);
 
-  return (S.n_elem > 0) ? S[0] : T(0);
+  const T out_val = (S.n_elem > 0) ? S[0] : T(0);
+
+  return (out_val <= T(0)) ? T(0) : out_val;
 }
 
 template <typename eT>
 inline typename get_pod_type<eT>::result op_norm::mat_norm_inf(const Mat<eT>& X) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // TODO: this can be sped up with a dedicated implementation
   return as_scalar(max(sum(abs(X), 1), 0));
